@@ -145,7 +145,7 @@ PdsMatrix *pds_matrix_new_load_data(const char* datafile)
 	fd=fopen(datafile,"r");
 	if(fd==NULL)	return NULL;
 
-	id=pds_ra_ncolumns_nlines_in_file(fd,&nc,&nl);
+	id=pds_load_number_of_columns_and_lines(fd,&nc,&nl);
 	if(id==FALSE)	
 	{
 		fclose(fd);
