@@ -1428,14 +1428,19 @@ int pds_vector_cmp(const PdsVector *Vector1,const PdsVector *Vector2,PdsRaNatura
 }
 
 
-/** \fn PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N
+/** \fn PdsVector *pds_vector_new_linspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
  *  \brief Crea un vector de tipo PdsVector e inicia sus valores con N elementos
- *  equidistantemente espaciados ((x2-x1)/(N-1)) entre x1 y x2 (inclusive).
- *  \param[in] N Es la longitud del vector.
+ *  equidistantemente espaciados entre xi y xf (inclusive).
+ *
+ *  \f[x_n=xi+n~\frac{(xf-xi)}{N-1}, ~\forall ~~n \in Z^+|~0 \leq n < N\f]
+ *
+ *  \param[in] xi Es el primer valor del vector.
+ *  \param[in] xf Es el último valor del vector.
+ *  \param[in] N Es numero de elementos del vector.
  *  \return Un puntero al vector de tipo PdsVector.
  *  \ingroup PdsVectorGroup
  */
-PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N)
+PdsVector *pds_vector_new_linspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
 {
     PdsVector *V=NULL;
     int i;
@@ -1443,7 +1448,39 @@ PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N)
     V=pds_vector_new(N);
     if(V==NULL) return NULL;
     
-    for(i=0;i<N;i++)    V->V[i]=x1+(x2-x1)*i/(N-1);
+    for(i=0;i<N;i++)    V->V[i]=xi+(xf-xi)*i/(N-1);
+
+    return V;
+}
+
+/** \fn PdsVector *pds_vector_new_logspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con N elementos
+ *  logaritmicamente espaciados entre xi y xf (inclusive).
+ *
+ *  \f[\alpha = \sqrt[N-1]{\frac{xf}{xi}}, ~ \forall~N>1, ~or~ \alpha=1\f]
+ *  \f[x_n=xi~\alpha^n \, ~\forall ~~n \in Z^+|~0 \leq n < N\f]
+ *
+ *  \param[in] xi Es el primer valor del vector. Este valor debe ser mayor que cero.
+ *  \param[in] xf Es el último valor del vector.
+ *  \param[in] N Es numero de elementos del vector. 
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_logspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
+{
+    PdsVector *V=NULL;
+    int i;
+    double alpha=1.0;
+
+    if(xi<=0)   return NULL;
+
+    V=pds_vector_new(N);
+    if(V==NULL) return NULL;
+
+
+    if(N>1) alpha=pow(xf/xi,1.0/(N-1.0));
+
+    for(i=0;i<N;i++)    V->V[i]=xi*pow(alpha,i*1.0);
 
     return V;
 }
@@ -1502,6 +1539,7 @@ PdsVector *pds_vector_new_hamming(PdsRaNatural N)
  *  de Blackman.
  *  \f[ W[n]=\frac{1-Alpha}{2}-\frac{1}{2} cos(2 \frac{\pi n}{N-1}) +\frac{Alpha}{2} cos(4 \frac{\pi n}{N-1}) ~~~ \forall 0 \leq n<N\f]
  *  \param[in] N Es la longitud del vector que representa la ventana de Blackman.
+ *  \param[in] Alpha Factor de configuración de la ventana de Blackman.
  *  \return Un puntero al vector de tipo PdsVector.
  *  \ingroup PdsVectorGroup
  */
@@ -1613,6 +1651,187 @@ int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char
 }
 
 
+/** \fn int pds_vector_octave_png_semilogx(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave (con la función semilogx de OCTAVE).
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_semilogx(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+{
+	int i;
+    int  FONTSIZE =18;
+    char IMGSIZE[]="800,600";
+	FILE *fd=NULL;
+	char *orden=NULL;
+
+	if(Y==NULL)		return FALSE;
+	if(labelx==NULL)	return FALSE;
+	if(labely==NULL)	return FALSE;
+	if(pngfile==NULL)	return FALSE;
+    if(X!=NULL)	if(X->Nel!=Y->Nel)	return FALSE;
+
+
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
+	if(fd==NULL)		return FALSE;
+	fprintf(fd,"Y=[");
+	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i]);
+	fprintf(fd,"];\n");
+    if(X==NULL)
+    {
+	    fprintf(fd,"N=length(Y);\n");
+	    fprintf(fd,"X=[0:N-1];\n");
+    }
+    else
+    {
+	    fprintf(fd,"X=[");
+    	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
+    	fprintf(fd,"];\n");
+    }
+	fprintf(fd,"semilogx(X,Y,\'o-\');\n");
+	fprintf(fd,"grid on;\n");
+	fprintf(fd,"xlabel(\'%s\');\n",labelx);
+	fprintf(fd,"ylabel(\'%s\');\n",labely);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S%s\');\n",pngfile,FONTSIZE,IMGSIZE);
+	fprintf(fd,"\n");
+	fprintf(fd,"\n");
+	fclose(fd);
+
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
+	if(orden==NULL)	return FALSE;
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
+	i=system(orden);
+
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
+	return TRUE;
+}
+
+/** \fn int pds_vector_octave_png_semilogy(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave (con la función semilogy de OCTAVE).
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_semilogy(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+{
+	int i;
+    int  FONTSIZE =18;
+    char IMGSIZE[]="800,600";
+	FILE *fd=NULL;
+	char *orden=NULL;
+
+	if(Y==NULL)		return FALSE;
+	if(labelx==NULL)	return FALSE;
+	if(labely==NULL)	return FALSE;
+	if(pngfile==NULL)	return FALSE;
+    if(X!=NULL)	if(X->Nel!=Y->Nel)	return FALSE;
+
+
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
+	if(fd==NULL)		return FALSE;
+	fprintf(fd,"Y=[");
+	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i]);
+	fprintf(fd,"];\n");
+    if(X==NULL)
+    {
+	    fprintf(fd,"N=length(Y);\n");
+	    fprintf(fd,"X=[0:N-1];\n");
+    }
+    else
+    {
+	    fprintf(fd,"X=[");
+    	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
+    	fprintf(fd,"];\n");
+    }
+	fprintf(fd,"semilogy(X,Y,\'o-\');\n");
+	fprintf(fd,"grid on;\n");
+	fprintf(fd,"xlabel(\'%s\');\n",labelx);
+	fprintf(fd,"ylabel(\'%s\');\n",labely);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S%s\');\n",pngfile,FONTSIZE,IMGSIZE);
+	fprintf(fd,"\n");
+	fprintf(fd,"\n");
+	fclose(fd);
+
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
+	if(orden==NULL)	return FALSE;
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
+	i=system(orden);
+
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
+	return TRUE;
+}
+
+
 /** \fn void pds_vector_free(PdsVector *Vector)
  *  \brief Libera la memoria de un vector de tipo puntero PdsVector.
  *  \param[in,out] Vector El vector a liberar.
