@@ -653,14 +653,35 @@ int pds_vector_set_gray(PdsVector *Vector,PdsRaNatural n,PdsRaNatural b0,PdsRaNa
 int pds_vector_cmp(const PdsVector *Vector1,const PdsVector *Vector2,PdsRaNatural *n);
 
 
-/** \fn PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N
+/** \fn PdsVector *pds_vector_new_linspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
  *  \brief Crea un vector de tipo PdsVector e inicia sus valores con N elementos
- *  equidistantemente espaciados ((x2-x1)/(N-1)) entre x1 y x2 (inclusive).
- *  \param[in] N Es la longitud del vector.
+ *  equidistantemente espaciados entre xi y xf (inclusive).
+ *
+ *  \f[x_n=xi+n~\frac{(xf-xi)}{N-1}, ~\forall ~~n \in Z^+|~0 \leq n < N\f]
+ *
+ *  \param[in] xi Es el primer valor del vector.
+ *  \param[in] xf Es el último valor del vector.
+ *  \param[in] N Es numero de elementos del vector.
  *  \return Un puntero al vector de tipo PdsVector.
  *  \ingroup PdsVectorGroup
  */
-PdsVector *pds_vector_new_linspace(PdsRaReal x1,PdsRaReal x2,PdsRaNatural N);
+PdsVector *pds_vector_new_linspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N);
+
+
+/** \fn PdsVector *pds_vector_new_logspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con N elementos
+ *  logaritmicamente espaciados entre xi y xf (inclusive).
+ *
+ *  \f[\alpha = \sqrt[N-1]{\frac{xf}{xi}}, ~ \forall~N>1, ~or~ \alpha=1\f]
+ *  \f[x_n=xi~\alpha^n \, ~\forall ~~n \in Z^+|~0 \leq n < N\f]
+ *
+ *  \param[in] xi Es el primer valor del vector. Este valor debe ser mayor que cero.
+ *  \param[in] xf Es el último valor del vector.
+ *  \param[in] N Es numero de elementos del vector. 
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_logspace(PdsRaReal xi,PdsRaReal xf,PdsRaNatural N);
 
 
 /** \fn PdsVector *pds_vector_new_rectangular(PdsRaNatural N)
@@ -690,6 +711,7 @@ PdsVector *pds_vector_new_hamming(PdsRaNatural N);
  *  de Blackman.
  *  \f[ W[n]=\frac{1-Alpha}{2}-\frac{1}{2} cos(2 \frac{\pi n}{N-1}) +\frac{Alpha}{2} cos(4 \frac{\pi n}{N-1}) ~~~ \forall 0 \leq n<N\f]
  *  \param[in] N Es la longitud del vector que representa la ventana de Blackman.
+ *  \param[in] Alpha Factor de configuración de la ventana de Blackman.
  *  \return Un puntero al vector de tipo PdsVector.
  *  \ingroup PdsVectorGroup
  */
@@ -715,6 +737,44 @@ PdsVector *pds_vector_new_blackman(PdsRaNatural N,PdsRaReal Alpha);
 int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile);
 
 
+/** \fn int pds_vector_octave_png_semilogx(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave (con la función semilogx de OCTAVE).
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_semilogx(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile);
+
+
+/** \fn int pds_vector_octave_png_semilogy(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave (con la función semilogy de OCTAVE).
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_semilogy(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile);
+
+
 /** \fn void pds_vector_free(PdsVector *Vector)
  *  \brief Libera la memoria de un vector de tipo puntero PdsVector.
  *  \param[in,out] Vector El vector a liberar.
